@@ -87,11 +87,11 @@ get '/ajax/content/search/device' => require_login sub {
 
     if ( request->is_ajax ) {
         my $json = to_json( \@results );
-        template 'ajax/search/device.tt', { results => $json }, { layout => undef };;
+        template 'ajax/search/device.tt', { results => $json }, { layout => 'noop' };;
     }
     else {
         header( 'Content-Type' => 'text/comma-separated-values' );
-        template 'ajax/search/device_csv.tt', { results => \@results, }, { layout => undef };
+        template 'ajax/search/device_csv.tt', { results => \@results, }, { layout => 'noop' };
     }
 };
 
